pub fn charge_history_growth(
gas_used: &mut u64,
ctx: &ArbPrecompileCtx,
gas: u64,
)Expand description
Charge precompile gas for emitting a log, recording it as HistoryGrowth.
pub fn charge_history_growth(
gas_used: &mut u64,
ctx: &ArbPrecompileCtx,
gas: u64,
)Charge precompile gas for emitting a log, recording it as HistoryGrowth.