insert_recent_wasm

Function insert_recent_wasm 

pub fn insert_recent_wasm(hash: B256) -> bool
Insert a Stylus program codehash into the recent WASMs cache. Returns true if the codehash was already present (cache hit).